@@ -24,11 +24,11 @@ WWW::Salesforce::Report - The poor man's Salesforce report API in Perl!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -789,8 +789,11 @@ sub get_report {
                   
         open my $fh,"<", $self->{ file } or
             croak "Could not open $self->{ file } : $!";
-    
-        $res = do { local $/; <$fh> };
+        
+        $res = "";
+        while( <$fh> ) {
+            $res .= $_;
+        }
         
         close $fh;
     }
